@@ -15,7 +15,7 @@ class RabbitMQ:
         self.virtualhost = kwargs.get('virtualhost') or '/'
         self.channel_pool = None
         self.loop = None
-        self.max_pool_size = kwargs.get('max_pool_size') or 20
+        self.max_pool_size = 1
 
     async def init(self, max_pool_size=None):
         if max_pool_size and isinstance(max_pool_size, int):
