@@ -55,7 +55,8 @@ class Downloader(object):
             await logger.info(f'{response.status_code}  {request.url}')
 
     async def request(self, url, params=None, headers=None, cookies=None, auth=None, proxies=None, allow_redirects=True,
-                      content=None, data=None, files=None, json=None, stream=False, timeout=30, cycle=3):
+                      verify=True, http2=False,  content=None, data=None, files=None, json=None, stream=False,
+                      timeout=30, cycle=3):
         if data or json or content:
             method = 'POST'
         else:
@@ -68,7 +69,7 @@ class Downloader(object):
             try:
                 if stream:
                     client = httpx.AsyncClient(proxies=proxies, event_hooks={'response': [self.log_response]},
-                                               follow_redirects=allow_redirects)
+                                               verify=verify, http2=http2, follow_redirects=allow_redirects)
                     request = client.build_request(method=method, url=url, headers=headers, cookies=cookies,
                                                    content=content, data=data, files=files, json=json, timeout=timeout)
                     resp = await client.send(request, stream=True)
@@ -76,7 +77,8 @@ class Downloader(object):
                     response.ok = True
                     response.client = client  # need aclose
                 else:
-                    async with httpx.AsyncClient(proxies=proxies, event_hooks={'response': [self.log_response]}) as client:
+                    async with httpx.AsyncClient(proxies=proxies, event_hooks={'response': [self.log_response]},
+                                                 verify=verify, http2=http2) as client:
                         resp = await client.request(
                             method=method, url=url, content=content, data=data, files=files, json=json, params=params,
                             headers=headers, cookies=cookies, auth=auth, follow_redirects=allow_redirects,
